@@ -63,6 +63,8 @@ DEFAULT_ATTEMPTS = 3
 
 ACTIVATION_CODE_ALLOWED = "BCDFGHJKLMNPQRSTVWXZ0123456789"
 
+SUPPORTED_PROTOCOL_VERSIONS = (26, 27, 28)
+
 
 def device_filter(advertisement_data: AdvertisementData) -> bool:
     """Return True if the device is supported."""
@@ -547,7 +549,7 @@ class DKEYLock:
 
     def _fire_callbacks(self, notifications: Notifications) -> None:
         """Fire the callbacks."""
-        _LOGGER.warning("_fire_callbacks")
+        _LOGGER.debug("_fire_callbacks")
         for callback in self._callbacks:
             callback(notifications)
 
@@ -936,7 +938,7 @@ class DKEYLock:
 
     def on_identification(self, identification: cmds.GetIdentificationRsp) -> None:
         """Handle identification from the lock."""
-        if identification.protocol_version != 27:
+        if identification.protocol_version not in SUPPORTED_PROTOCOL_VERSIONS:
             raise UnsupportedProtocolVersion(identification.protocol_version)
         self.device_info.sw_version = identification.sw_version
         self.device_info.device_id = f"{identification.key_holder_id.hex()}"
@@ -948,7 +950,7 @@ class DKEYLock:
     def on_notification(self, notifications: Notifications) -> None:
         """Handle status notifications from the lock."""
         self.state.update(notifications)
-        _LOGGER.info("Lock state: %s", self.state)
+        _LOGGER.debug("Lock state: %s", self.state)
         self._fire_callbacks(notifications)
 
     def receive_notifications(
